<?php

require_once 'Gtf.class.inc';
require_once dirname($_SERVER['SCRIPT_FILENAME']) . '/class/vitis_lib/Connection.class.inc';
require_once dirname($_SERVER['SCRIPT_FILENAME']) . '/class/vmlib/files/Files_manager.class.inc';

/**
 * \file Workspace.class.inc
 * \class Workspace
 *
 * \author Yoann Perollet <yoann.perollet@veremes.com>.
 *
 * 	\brief This file contains the Workspace php class
 *
 * This class defines operation for one Workspace
 *
 */
class Workspace extends GTF {

    public $oError;

    /**
     * construct
     * @param type $aPath url of the request
     * @param type $aValues parameters of the request
     * @param type $properties properties
     * @param type $bShortcut false to reinit variables
     * @param type $oConnection connection object
     */
    function __construct($aPath, $aValues, $properties, $bShortcut = false, $oConnection = false) {
        parent::__construct($aPath, $aValues, $properties, $bShortcut, $oConnection);
        $this->aSelectedFields = Array('workspace_id', 'name', 'owner', $this->getDateSelectedFields('creation_date', 'yeartosecond'), 'description', 'subscription', 'category_id', 'success_action_id', 'failed_action_id', 'survey', 'form_type', 'legal_terms_conditions', $this->getDateSelectedFields('last_save_date', 'yeartosecond'), 'last_save_build', 'file_encoding', 'title', 'requirements', 'history', 'usage', 'key', 'email_template_id', 'locked', 'tag', 'groups', 'login', 'category_name', 'email_template', 'fmw_file', 'dataencrypt', 'usepersonaldata', 'unitcost', 'costpersecond');
    }

    /**
     * @SWG\Get(path="/workspaces/{workspace_id}",
     *   tags={"Workspaces"},
     *   summary="Get Workspace",
     *   description="Request to get Workspace by id",
     *   operationId="GET",
     *   produces={"application/xml", "application/json"},
     *   @SWG\Parameter(
     *     name="token",
     *     in="query",
     *     description="user token",
     *     required=true,
     *     type="string"
     *   ),
     *   @SWG\Parameter(
     *     name="workspace_id",
     *     in="path",
     *     description="workspace id",
     *     required=true,
     *     type="string"
     *   ),
     *   @SWG\Parameter(
     *     name="attributs",
     *     in="query",
     *     description="list of attributs",
     *     required=false,
     *     type="string"
     *   ),
     *   @SWG\Parameter(
     *     name="form",
     *     in="query",
     *     description="form to load",
     *     required=false,
     *     type="string"
     *   ),
     *   @SWG\Response(
     *         response=200,
     *         description="Poprerties Response",
     *         @SWG\Schema(ref="#/definitions/workspaces")
     *     )
     *  )
     */
    /**
     * @SWG\Get(path="/workspaces/{workspace_id}/Tree",
     *   tags={"Workspaces"},
     *   summary="Get Workspace directory tree",
     *   description="Request to get Workspace directory tree by id",
     *   operationId="GET",
     *   produces={"application/xml", "application/json"},
     *   @SWG\Parameter(
     *     name="token",
     *     in="query",
     *     description="user token",
     *     required=true,
     *     type="string"
     *   ),
     *   @SWG\Parameter(
     *     name="workspace_id",
     *     in="path",
     *     description="workspace id",
     *     required=true,
     *     type="string"
     *   ),
     *   @SWG\Response(
     *         response=200,
     *         description="Poprerties Response",
     *         @SWG\Schema(ref="#/definitions/workspaces")
     *     )
     *  )
     */
    /**
     * @SWG\Get(path="/workspaces/{workspace_id}/File",
     *   tags={"Workspaces"},
     *   summary="Get Workspace file",
     *   description="Request to get a file from the workspace directory",
     *   operationId="GET",
     *   produces={"application/xml", "application/json"},
     *   @SWG\Parameter(
     *     name="token",
     *     in="query",
     *     description="user token",
     *     required=true,
     *     type="string"
     *   ),
     *   @SWG\Parameter(
     *     name="workspace_id",
     *     in="path",
     *     description="workspace id",
     *     required=true,
     *     type="string"
     *   ),
     *   @SWG\Parameter(
     *     name="file_name",
     *     in="query",
     *     description="file name",
     *     required=true,
     *     type="string"
     *   ),
     *   @SWG\Response(
     *         response=200,
     *         description="Poprerties Response",
     *         @SWG\Schema(ref="#/definitions/workspaces")
     *     )
     *  )
     */
    /**
     * @SWG\Get(path="/workspaces/{workspace_id}/Metadata",
     *   tags={"Workspaces"},
     *   summary="Regenerate workspace metadata",
     *   description="Request to regenerate the metadata of a workspace",
     *   operationId="GET",
     *   produces={"application/xml", "application/json"},
     *   @SWG\Parameter(
     *     name="token",
     *     in="query",
     *     description="user token",
     *     required=true,
     *     type="string"
     *   ),
     *   @SWG\Parameter(
     *     name="workspace_id",
     *     in="path",
     *     description="workspace id",
     *     required=true,
     *     type="string"
     *   ),
     *   @SWG\Response(
     *         response=200,
     *         description="Properties Response",
     *         @SWG\Schema(ref="#/definitions/workspaces")
     *     )
     *  )
     */

    /**
     * get informations about workspace
     */
    function GET() {
        $oFilesManager = new Files_manager($this->aProperties);
        if (!empty($this->aValues["form"])) {
            require $this->sRessourcesFile;
            $this->aFields = $this->getFields($this->aProperties['schema_gtf'], "v_workspace", "workspace_id");
            // Groupes rattachés au projet FME.
            $this->getGroups();
            // Fichier de formulaire.
            if ($this->aValues["form"] == 'Default')
                $sFile = 'DSubform.json';
            else if ($this->aValues["form"] == 'Perso')
                $sFile = 'WSubform.json';
            else if ($this->aValues["form"] == 'Published')
                $sFile = 'Subform.json';
            else {
                writeToErrorLog("Error parameter is not a known mode user :" . $_SESSION["user_id"]);
                $this->oError = new VitisError(1, "Error parameter is not a known mode");
            }
            // Contenu du fichier de formulaire.
            $sDirPath = $this->aProperties['workspace_dir'] . '/' . $this->aValues["my_vitis_id"];
            $sFileContent = $oFilesManager->oFileInterface->file_get_contents($sDirPath . '/form/' . $sFile);
            if ($sFileContent !== false) {
                $aJson = json_decode($sFileContent, true);
                $this->aFields["json_form"] = array($aJson);
                $sJs = "";
                $sCss = "";
                // Url du fichier js du formulaire.
                $sFileUrl = $oFilesManager->oFileInterface->getProxyPassUrl($sDirPath . '/form/ressources/Subform.js');
                $sJs = $sFileUrl;
                // Url du fichier css du formulaire.
                $sFileUrl = $oFilesManager->oFileInterface->getProxyPassUrl($sDirPath . '/form/ressources/Subform.css');
                $sCss = $sFileUrl;
                //
                array_push($this->aFields["json_form"], $sJs);
                array_push($this->aFields["json_form"], $sCss);
            }
            else
                $this->oError = new VitisError(1, "File not found");
        } else {
            require $this->sRessourcesFile;
            $this->aFields = $this->getFields($this->aProperties['schema_gtf'], "v_workspace", "workspace_id");
            $this->getGroups();
            // Url vers le fichier fmw du projet.
            if (!empty($this->aFields['fmw_file'])) {
                $sFilePath = $this->aProperties['workspace_dir'] . '/' . $this->aValues['my_vitis_id'] . '/fme/' . $this->aFields['fmw_file'];
                $sFmwFileUrl = $oFilesManager->oFileInterface->getProxyPassUrl($sFilePath);
                if (!empty($sFmwFileUrl))
                    $this->aFields['fmw_file_url'] = $sFmwFileUrl;
            }
        }
        // Formatage de la colonne "form_type".
        $sFilePath = $this->aProperties['workspace_dir'] . '/' . $this->aValues["my_vitis_id"] . '/form/Subform.json';
        if (!$oFilesManager->oFileInterface->file_exists($sFilePath))
            $this->aFields['form_type'] = '';
        else {
            if ($this->aFields['form_type'] != "custom")
                $this->aFields['form_type'] = "default";
        }
    }

    function getGroups() {
        require $this->sRessourcesFile;
        if (in_array("groups", $this->aSelectedFields)) {
            $aParams['sSchemaGtf'] = array('value' => $this->aProperties['schema_gtf'], 'type' => 'schema_name');
            $aParams['sSchemaFramework'] = array('value' => $this->aProperties['schema_framework'], 'type' => 'schema_name');
            $aParams['workspace_id'] = array('value' => $this->aValues['my_vitis_id'], 'type' => 'number');
            $oPDOresult = $this->oConnection->oBd->executeWithParams($aSql['getWorkspaceGroups'], $aParams);
            $sListGroupId = "";
            $aListGroupName = array();
            while ($aLigne = $this->oConnection->oBd->ligneSuivante($oPDOresult)) {
                if ($sListGroupId == "") {
                    $sListGroupId = $aLigne["group_id"];
                } else {
                    $sListGroupId .= "|" . $aLigne["group_id"];
                }
                $aListGroupName[] = $aLigne["name"];
            }
            $oPDOresult = $this->oConnection->oBd->fermeResultat();
            $this->aFields['groups'] = $sListGroupId;
            $this->aFields['groups_label'] = implode(',', $aListGroupName);
        }
    }

    /**
     * delete a workspace
     */
    function DELETE() {
        $this->oConnection->oBd->delete($this->aProperties['schema_gtf'], 'workspace', 'workspace_id', $this->aValues["my_vitis_id"], 'integer');
        if ($this->oConnection->oBd->enErreur()) {
            $this->oError = new VitisError(1, $this->oConnection->oBd->getBDMessage());
        } else {
            // Suppression du répertoire du projet FME.
            $oFilesManager = new Files_manager($this->aProperties);
            $sDirPath = $this->aProperties['workspace_dir'] . '/' . $this->aValues["my_vitis_id"];
            $oFilesManager->oFileInterface->clearDir($sDirPath);
        }
    }

}

?>
